@@ -4,6 +4,8 @@
 #	20010224 Luca De Vitis <luca@debian.org>
 #	20020116 Ola Lundqvist <opal@debian.org>
 #		Documented the error variable.
+#	20041002 Raphal Enrici <blacknoz@club-internet.fr>
+#		Quoted $dbuser so that the username can contain '-'.
 # Needs:	$dbuser    - the user name to drop
 #		$dbname    - the database that user should have access to.
 #		$dbpass    - the password to use.
@@ -38,15 +40,13 @@ elif ! eval $pgsqlcmd -q -d $systemdb -c "\"SELECT usename FROM pg_shadow;\"" >/
 else
     TMPU=$(eval $pgsqlcmd -d $systemdb -q -t -A -c "\"SELECT usename FROM pg_shadow WHERE usename='$dbuser';\"")
     if [ "$TMPU" = "$dbuser" ] ; then
-	if eval $pgsqlcmd -q -d $systemdb -c "\"
-	DELETE FROM pg_shadow
-	WHERE usename='$dbuser';\"" ; then
+	if eval $pgsqlcmd -q -d $systemdb -c "\"DROP USER "'\"'"$dbuser"'\"'";\"" ; then
 	    TMPU=$(eval $pgsqlcmd -d $systemdb -q -t -A -c "\"SELECT usename FROM pg_shadow WHERE usename='$dbuser';\"")
 	    if [ -z "$TMPU" ] ; then
-		log="${log}User $dbuser droped."
+		log="${log}User $dbuser dropped."
 		status=drop
 	    else
-		error="User $dbuser NOT successfully droped. You have to do it manually."
+		error="User $dbuser NOT successfully dropped. You have to do it manually."
 	    fi
 	else
 	    error="Unable to run the drop user script."
